[wtl] Add two "post-release updates". (#21924)

* [wtl] Add two "post-release updates".

See https://sourceforge.net/projects/wtl/files/WTL%2010/WTL10%20Post-Release%20Updates.txt/download

* Ran magic undocumented command line.
This commit is contained in:
Christian Ullrich 2021-12-10 02:56:38 +01:00 committed by GitHub
parent adc3cec1fc
commit 34a73b5010
No known key found for this signature in database
GPG Key ID: 4AEE18F83AFDEB23
6 changed files with 56 additions and 2 deletions

View File

@ -0,0 +1,35 @@
--- a/Include/atlmisc.h
+++ b/Include/atlmisc.h
@@ -628,7 +628,7 @@
{
ATLASSERT(m_hFind != NULL);
- ATL::CString strResult("file://");
+ ATL::CString strResult(_T("file://"));
strResult += GetFilePath();
return strResult;
}

View File

@ -5,6 +5,9 @@ vcpkg_from_sourceforge(
FILENAME "WTL10_10320_Release.zip"
NO_REMOVE_ONE_LEVEL
SHA512 086a6cf6a49a4318a8c519136ba6019ded7aa7f2c1d85f78c30b21183654537b3428a400a64fcdacba3a7a10a9ef05137b6f2119f59594da300d55f9ebfb1309
PATCHES
appwizard_setup.js-vs2022.patch
atlmisc.h-bug329.patch
)
file(INSTALL ${SOURCE_PATH}/Include/ DESTINATION ${CURRENT_PACKAGES_DIR}/include/${PORT} FILES_MATCHING PATTERN "*.h")

View File

@ -1,7 +1,7 @@
{
"name": "wtl",
"version-string": "10.0.10320",
"port-version": 1,
"port-version": 2,
"description": "Windows Template Library (WTL) is a C++ library for developing Windows applications and UI components.",
"homepage": "https://sourceforge.net/projects/wtl/"
}

View File

@ -7270,7 +7270,7 @@
},
"wtl": {
"baseline": "10.0.10320",
"port-version": 1
"port-version": 2
},
"wxchartdir": {
"baseline": "1.0.0",

View File

@ -1,5 +1,10 @@
{
"versions": [
{
"git-tree": "3345336300f47e924a80d3be0f3fb76c558a54fe",
"version-string": "10.0.10320",
"port-version": 2
},
{
"git-tree": "6d429012165553d38ea4ae45057ce85bb34deb96",
"version-string": "10.0.10320",
--- a/AppWizard/Setup.js
+++ b/AppWizard/Setup.js
@@ -185,26 +185,30 @@
}
}
-// Search for Visual Studio 2017-2019
- var nVersionsNew = 2;
+// Search for Visual Studio 2017/2019/2022
+ var nVersionsNew = 3;
var strWizardFolderNew = "Common7\\IDE\\VC\\vcprojects";
var astrVersionsNew = new Array();
astrVersionsNew[0] = "Visual Studio 2017 (15.0)";
astrVersionsNew[1] = "Visual Studio 2019 (16.0)";
+ astrVersionsNew[2] = "Visual Studio 2022 (17.0)";
var astrWizVerNew = new Array();
astrWizVerNew[0] = "15.0";
astrWizVerNew[1] = "16.0";
+ astrWizVerNew[2] = "17.0";
var astrParamVerNew = new Array();
astrParamVerNew[0] = "15";
astrParamVerNew[1] = "16";
+ astrParamVerNew[2] = "17";
var astrFilterVer = new Array();
astrFilterVer[0] = "[15.0,16.0]";
astrFilterVer[1] = "[16.0,17.0]";
+ astrFilterVer[2] = "[17.0,18.0]";
// Ensure that we can run vswhere.exe
var strProgFileRegKey_x86 = "HKLM\\Software\\Microsoft\\Windows\\CurrentVersion\\ProgramFilesDir (x86)";

View File

@ -0,0 +1,11 @@